"""_1315.py

OnLoadElectricMachineResults
"""


from mastapy._internal import constructor, enum_with_selected_value_runtime, conversion
from mastapy.electric_machines.load_cases_and_analyses import _1330
from mastapy.electric_machines import _1293
from mastapy.electric_machines.results import _1299
from mastapy._internal.python_net import python_net_import

_ON_LOAD_ELECTRIC_MACHINE_RESULTS = python_net_import('SMT.MastaAPI.ElectricMachines.Results', 'OnLoadElectricMachineResults')


__docformat__ = 'restructuredtext en'
__all__ = ('OnLoadElectricMachineResults',)


class OnLoadElectricMachineResults(_1299.ElectricMachineResults):
    """OnLoadElectricMachineResults

    This is a mastapy class.
    """

    TYPE = _ON_LOAD_ELECTRIC_MACHINE_RESULTS

    def __init__(self, instance_to_wrap: 'OnLoadElectricMachineResults.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def average_power_factor(self) -> 'float':
        """float: 'AveragePowerFactor' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.AveragePowerFactor

        if temp is None:
            return 0.0

        return temp

    @property
    def average_power_factor_angle(self) -> 'float':
        """float: 'AveragePowerFactorAngle' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.AveragePowerFactorAngle

        if temp is None:
            return 0.0

        return temp

    @property
    def average_power_factor_with_harmonic_distortion_adjustment(self) -> 'float':
        """float: 'AveragePowerFactorWithHarmonicDistortionAdjustment' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.AveragePowerFactorWithHarmonicDistortionAdjustment

        if temp is None:
            return 0.0

        return temp

    @property
    def average_torque_dq(self) -> 'float':
        """float: 'AverageTorqueDQ' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.AverageTorqueDQ

        if temp is None:
            return 0.0

        return temp

    @property
    def dc_winding_losses(self) -> 'float':
        """float: 'DCWindingLosses' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.DCWindingLosses

        if temp is None:
            return 0.0

        return temp

    @property
    def efficiency(self) -> 'float':
        """float: 'Efficiency' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.Efficiency

        if temp is None:
            return 0.0

        return temp

    @property
    def electrical_loading(self) -> 'float':
        """float: 'ElectricalLoading' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ElectricalLoading

        if temp is None:
            return 0.0

        return temp

    @property
    def input_power(self) -> 'float':
        """float: 'InputPower' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.InputPower

        if temp is None:
            return 0.0

        return temp

    @property
    def line_resistance(self) -> 'float':
        """float: 'LineResistance' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.LineResistance

        if temp is None:
            return 0.0

        return temp

    @property
    def line_to_line_terminal_voltage_peak(self) -> 'float':
        """float: 'LineToLineTerminalVoltagePeak' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.LineToLineTerminalVoltagePeak

        if temp is None:
            return 0.0

        return temp

    @property
    def line_to_line_terminal_voltage_rms(self) -> 'float':
        """float: 'LineToLineTerminalVoltageRMS' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.LineToLineTerminalVoltageRMS

        if temp is None:
            return 0.0

        return temp

    @property
    def line_to_line_terminal_voltage_total_harmonic_distortion(self) -> 'float':
        """float: 'LineToLineTerminalVoltageTotalHarmonicDistortion' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.LineToLineTerminalVoltageTotalHarmonicDistortion

        if temp is None:
            return 0.0

        return temp

    @property
    def motor_constant(self) -> 'float':
        """float: 'MotorConstant' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.MotorConstant

        if temp is None:
            return 0.0

        return temp

    @property
    def output_power(self) -> 'float':
        """float: 'OutputPower' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.OutputPower

        if temp is None:
            return 0.0

        return temp

    @property
    def phase_resistance(self) -> 'float':
        """float: 'PhaseResistance' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.PhaseResistance

        if temp is None:
            return 0.0

        return temp

    @property
    def phase_resistive_voltage_peak(self) -> 'float':
        """float: 'PhaseResistiveVoltagePeak' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.PhaseResistiveVoltagePeak

        if temp is None:
            return 0.0

        return temp

    @property
    def phase_resistive_voltage_rms(self) -> 'float':
        """float: 'PhaseResistiveVoltageRMS' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.PhaseResistiveVoltageRMS

        if temp is None:
            return 0.0

        return temp

    @property
    def phase_resistive_voltage_drms(self) -> 'float':
        """float: 'PhaseResistiveVoltageDRMS' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.PhaseResistiveVoltageDRMS

        if temp is None:
            return 0.0

        return temp

    @property
    def phase_resistive_voltage_qrms(self) -> 'float':
        """float: 'PhaseResistiveVoltageQRMS' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.PhaseResistiveVoltageQRMS

        if temp is None:
            return 0.0

        return temp

    @property
    def phase_terminal_voltage_peak(self) -> 'float':
        """float: 'PhaseTerminalVoltagePeak' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.PhaseTerminalVoltagePeak

        if temp is None:
            return 0.0

        return temp

    @property
    def phase_terminal_voltage_rms(self) -> 'float':
        """float: 'PhaseTerminalVoltageRMS' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.PhaseTerminalVoltageRMS

        if temp is None:
            return 0.0

        return temp

    @property
    def phase_terminal_voltage_total_harmonic_distortion(self) -> 'float':
        """float: 'PhaseTerminalVoltageTotalHarmonicDistortion' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.PhaseTerminalVoltageTotalHarmonicDistortion

        if temp is None:
            return 0.0

        return temp

    @property
    def power_factor_direction(self) -> '_1330.LeadingOrLagging':
        """LeadingOrLagging: 'PowerFactorDirection' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.PowerFactorDirection

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(temp)
        return constructor.new_from_mastapy_type(_1330.LeadingOrLagging)(value) if value is not None else None

    @property
    def stall_current(self) -> 'float':
        """float: 'StallCurrent' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.StallCurrent

        if temp is None:
            return 0.0

        return temp

    @property
    def stall_torque(self) -> 'float':
        """float: 'StallTorque' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.StallTorque

        if temp is None:
            return 0.0

        return temp

    @property
    def torque_constant(self) -> 'float':
        """float: 'TorqueConstant' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.TorqueConstant

        if temp is None:
            return 0.0

        return temp

    @property
    def torque_ripple_percentage_mst(self) -> 'float':
        """float: 'TorqueRipplePercentageMST' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.TorqueRipplePercentageMST

        if temp is None:
            return 0.0

        return temp

    @property
    def total_power_loss(self) -> 'float':
        """float: 'TotalPowerLoss' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.TotalPowerLoss

        if temp is None:
            return 0.0

        return temp

    @property
    def winding_material_resistivity(self) -> 'float':
        """float: 'WindingMaterialResistivity' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.WindingMaterialResistivity

        if temp is None:
            return 0.0

        return temp

    @property
    def winding_skin_depth(self) -> 'float':
        """float: 'WindingSkinDepth' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.WindingSkinDepth

        if temp is None:
            return 0.0

        return temp

    @property
    def windings(self) -> '_1293.Windings':
        """Windings: 'Windings' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.Windings

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None



"""__init__.py"""


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._895 import BarForPareto
    from ._896 import CandidateDisplayChoice
    from ._897 import ChartInfoBase
    from ._898 import CylindricalGearSetParetoOptimiser
    from ._899 import DesignSpaceSearchBase
    from ._900 import DesignSpaceSearchCandidateBase
    from ._901 import FaceGearSetParetoOptimiser
    from ._902 import GearNameMapper
    from ._903 import GearNamePicker
    from ._904 import GearSetOptimiserCandidate
    from ._905 import GearSetParetoOptimiser
    from ._906 import HypoidGearSetParetoOptimiser
    from ._907 import InputSliderForPareto
    from ._908 import LargerOrSmaller
    from ._909 import MicroGeometryDesignSpaceSearch
    from ._910 import MicroGeometryDesignSpaceSearchCandidate
    from ._911 import MicroGeometryDesignSpaceSearchChartInformation
    from ._912 import MicroGeometryGearSetDesignSpaceSearch
    from ._913 import MicroGeometryGearSetDesignSpaceSearchStrategyDatabase
    from ._914 import MicroGeometryGearSetDutyCycleDesignSpaceSearchStrategyDatabase
    from ._915 import OptimisationTarget
    from ._916 import ParetoConicalRatingOptimisationStrategyDatabase
    from ._917 import ParetoCylindricalGearSetDutyCycleOptimisationStrategyDatabase
    from ._918 import ParetoCylindricalGearSetOptimisationStrategyDatabase
    from ._919 import ParetoCylindricalRatingOptimisationStrategyDatabase
    from ._920 import ParetoFaceGearSetDutyCycleOptimisationStrategyDatabase
    from ._921 import ParetoFaceGearSetOptimisationStrategyDatabase
    from ._922 import ParetoFaceRatingOptimisationStrategyDatabase
    from ._923 import ParetoHypoidGearSetDutyCycleOptimisationStrategyDatabase
    from ._924 import ParetoHypoidGearSetOptimisationStrategyDatabase
    from ._925 import ParetoOptimiserChartInformation
    from ._926 import ParetoSpiralBevelGearSetDutyCycleOptimisationStrategyDatabase
    from ._927 import ParetoSpiralBevelGearSetOptimisationStrategyDatabase
    from ._928 import ParetoStraightBevelGearSetDutyCycleOptimisationStrategyDatabase
    from ._929 import ParetoStraightBevelGearSetOptimisationStrategyDatabase
    from ._930 import ReasonsForInvalidDesigns
    from ._931 import SpiralBevelGearSetParetoOptimiser
    from ._932 import StraightBevelGearSetParetoOptimiser



"""_7383.py

CylindricalGearCompoundAdvancedSystemDeflection
"""


from typing import List

from mastapy.system_model.part_model.gears import _2481, _2483
from mastapy._internal import constructor, conversion
from mastapy._internal.cast_exception import CastException
from mastapy.gears.rating.cylindrical import _449
from mastapy.system_model.analyses_and_results.advanced_system_deflections import _7251
from mastapy.system_model.analyses_and_results.advanced_system_deflections.compound import _7394
from mastapy._internal.python_net import python_net_import

_CYLINDRICAL_GEAR_COMPOUND_ADVANCED_SYSTEM_DEFLECTION = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.AdvancedSystemDeflections.Compound', 'CylindricalGearCompoundAdvancedSystemDeflection')


__docformat__ = 'restructuredtext en'
__all__ = ('CylindricalGearCompoundAdvancedSystemDeflection',)


class CylindricalGearCompoundAdvancedSystemDeflection(_7394.GearCompoundAdvancedSystemDeflection):
    """CylindricalGearCompoundAdvancedSystemDeflection

    This is a mastapy class.
    """

    TYPE = _CYLINDRICAL_GEAR_COMPOUND_ADVANCED_SYSTEM_DEFLECTION

    def __init__(self, instance_to_wrap: 'CylindricalGearCompoundAdvancedSystemDeflection.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def component_design(self) -> '_2481.CylindricalGear':
        """CylindricalGear: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ComponentDesign

        if temp is None:
            return None

        if _2481.CylindricalGear.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast component_design to CylindricalGear. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def gear_duty_cycle_rating(self) -> '_449.CylindricalGearDutyCycleRating':
        """CylindricalGearDutyCycleRating: 'GearDutyCycleRating' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.GearDutyCycleRating

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def cylindrical_gear_rating(self) -> '_449.CylindricalGearDutyCycleRating':
        """CylindricalGearDutyCycleRating: 'CylindricalGearRating' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.CylindricalGearRating

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def component_analysis_cases_ready(self) -> 'List[_7251.CylindricalGearAdvancedSystemDeflection]':
        """List[CylindricalGearAdvancedSystemDeflection]: 'ComponentAnalysisCasesReady' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ComponentAnalysisCasesReady

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)
        return value

    @property
    def planetaries(self) -> 'List[CylindricalGearCompoundAdvancedSystemDeflection]':
        """List[CylindricalGearCompoundAdvancedSystemDeflection]: 'Planetaries' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.Planetaries

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)
        return value

    @property
    def component_analysis_cases(self) -> 'List[_7251.CylindricalGearAdvancedSystemDeflection]':
        """List[CylindricalGearAdvancedSystemDeflection]: 'ComponentAnalysisCases' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ComponentAnalysisCases

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)
        return value



"""__init__.py"""


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._6341 import AbstractAssemblyCompoundDynamicAnalysis
    from ._6342 import AbstractShaftCompoundDynamicAnalysis
    from ._6343 import AbstractShaftOrHousingCompoundDynamicAnalysis
    from ._6344 import AbstractShaftToMountableComponentConnectionCompoundDynamicAnalysis
    from ._6345 import AGMAGleasonConicalGearCompoundDynamicAnalysis
    from ._6346 import AGMAGleasonConicalGearMeshCompoundDynamicAnalysis
    from ._6347 import AGMAGleasonConicalGearSetCompoundDynamicAnalysis
    from ._6348 import AssemblyCompoundDynamicAnalysis
    from ._6349 import BearingCompoundDynamicAnalysis
    from ._6350 import BeltConnectionCompoundDynamicAnalysis
    from ._6351 import BeltDriveCompoundDynamicAnalysis
    from ._6352 import BevelDifferentialGearCompoundDynamicAnalysis
    from ._6353 import BevelDifferentialGearMeshCompoundDynamicAnalysis
    from ._6354 import BevelDifferentialGearSetCompoundDynamicAnalysis
    from ._6355 import BevelDifferentialPlanetGearCompoundDynamicAnalysis
    from ._6356 import BevelDifferentialSunGearCompoundDynamicAnalysis
    from ._6357 import BevelGearCompoundDynamicAnalysis
    from ._6358 import BevelGearMeshCompoundDynamicAnalysis
    from ._6359 import BevelGearSetCompoundDynamicAnalysis
    from ._6360 import BoltCompoundDynamicAnalysis
    from ._6361 import BoltedJointCompoundDynamicAnalysis
    from ._6362 import ClutchCompoundDynamicAnalysis
    from ._6363 import ClutchConnectionCompoundDynamicAnalysis
    from ._6364 import ClutchHalfCompoundDynamicAnalysis
    from ._6365 import CoaxialConnectionCompoundDynamicAnalysis
    from ._6366 import ComponentCompoundDynamicAnalysis
    from ._6367 import ConceptCouplingCompoundDynamicAnalysis
    from ._6368 import ConceptCouplingConnectionCompoundDynamicAnalysis
    from ._6369 import ConceptCouplingHalfCompoundDynamicAnalysis
    from ._6370 import ConceptGearCompoundDynamicAnalysis
    from ._6371 import ConceptGearMeshCompoundDynamicAnalysis
    from ._6372 import ConceptGearSetCompoundDynamicAnalysis
    from ._6373 import ConicalGearCompoundDynamicAnalysis
    from ._6374 import ConicalGearMeshCompoundDynamicAnalysis
    from ._6375 import ConicalGearSetCompoundDynamicAnalysis
    from ._6376 import ConnectionCompoundDynamicAnalysis
    from ._6377 import ConnectorCompoundDynamicAnalysis
    from ._6378 import CouplingCompoundDynamicAnalysis
    from ._6379 import CouplingConnectionCompoundDynamicAnalysis
    from ._6380 import CouplingHalfCompoundDynamicAnalysis
    from ._6381 import CVTBeltConnectionCompoundDynamicAnalysis
    from ._6382 import CVTCompoundDynamicAnalysis
    from ._6383 import CVTPulleyCompoundDynamicAnalysis
    from ._6384 import CycloidalAssemblyCompoundDynamicAnalysis
    from ._6385 import CycloidalDiscCentralBearingConnectionCompoundDynamicAnalysis
    from ._6386 import CycloidalDiscCompoundDynamicAnalysis
    from ._6387 import CycloidalDiscPlanetaryBearingConnectionCompoundDynamicAnalysis
    from ._6388 import CylindricalGearCompoundDynamicAnalysis
    from ._6389 import CylindricalGearMeshCompoundDynamicAnalysis
    from ._6390 import CylindricalGearSetCompoundDynamicAnalysis
    from ._6391 import CylindricalPlanetGearCompoundDynamicAnalysis
    from ._6392 import DatumCompoundDynamicAnalysis
    from ._6393 import ExternalCADModelCompoundDynamicAnalysis
    from ._6394 import FaceGearCompoundDynamicAnalysis
    from ._6395 import FaceGearMeshCompoundDynamicAnalysis
    from ._6396 import FaceGearSetCompoundDynamicAnalysis
    from ._6397 import FEPartCompoundDynamicAnalysis
    from ._6398 import FlexiblePinAssemblyCompoundDynamicAnalysis
    from ._6399 import GearCompoundDynamicAnalysis
    from ._6400 import GearMeshCompoundDynamicAnalysis
    from ._6401 import GearSetCompoundDynamicAnalysis
    from ._6402 import GuideDxfModelCompoundDynamicAnalysis
    from ._6403 import HypoidGearCompoundDynamicAnalysis
    from ._6404 import HypoidGearMeshCompoundDynamicAnalysis
    from ._6405 import HypoidGearSetCompoundDynamicAnalysis
    from ._6406 import InterMountableComponentConnectionCompoundDynamicAnalysis
    from ._6407 import KlingelnbergCycloPalloidConicalGearCompoundDynamicAnalysis
    from ._6408 import KlingelnbergCycloPalloidConicalGearMeshCompoundDynamicAnalysis
    from ._6409 import KlingelnbergCycloPalloidConicalGearSetCompoundDynamicAnalysis
    from ._6410 import KlingelnbergCycloPalloidHypoidGearCompoundDynamicAnalysis
    from ._6411 import KlingelnbergCycloPalloidHypoidGearMeshCompoundDynamicAnalysis
    from ._6412 import KlingelnbergCycloPalloidHypoidGearSetCompoundDynamicAnalysis
    from ._6413 import KlingelnbergCycloPalloidSpiralBevelGearCompoundDynamicAnalysis
    from ._6414 import KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundDynamicAnalysis
    from ._6415 import KlingelnbergCycloPalloidSpiralBevelGearSetCompoundDynamicAnalysis
    from ._6416 import MassDiscCompoundDynamicAnalysis
    from ._6417 import MeasurementComponentCompoundDynamicAnalysis
    from ._6418 import MountableComponentCompoundDynamicAnalysis
    from ._6419 import OilSealCompoundDynamicAnalysis
    from ._6420 import PartCompoundDynamicAnalysis
    from ._6421 import PartToPartShearCouplingCompoundDynamicAnalysis
    from ._6422 import PartToPartShearCouplingConnectionCompoundDynamicAnalysis
    from ._6423 import PartToPartShearCouplingHalfCompoundDynamicAnalysis
    from ._6424 import PlanetaryConnectionCompoundDynamicAnalysis
    from ._6425 import PlanetaryGearSetCompoundDynamicAnalysis
    from ._6426 import PlanetCarrierCompoundDynamicAnalysis
    from ._6427 import PointLoadCompoundDynamicAnalysis
    from ._6428 import PowerLoadCompoundDynamicAnalysis
    from ._6429 import PulleyCompoundDynamicAnalysis
    from ._6430 import RingPinsCompoundDynamicAnalysis
    from ._6431 import RingPinsToDiscConnectionCompoundDynamicAnalysis
    from ._6432 import RollingRingAssemblyCompoundDynamicAnalysis
    from ._6433 import RollingRingCompoundDynamicAnalysis
    from ._6434 import RollingRingConnectionCompoundDynamicAnalysis
    from ._6435 import RootAssemblyCompoundDynamicAnalysis
    from ._6436 import ShaftCompoundDynamicAnalysis
    from ._6437 import ShaftHubConnectionCompoundDynamicAnalysis
    from ._6438 import ShaftToMountableComponentConnectionCompoundDynamicAnalysis
    from ._6439 import SpecialisedAssemblyCompoundDynamicAnalysis
    from ._6440 import SpiralBevelGearCompoundDynamicAnalysis
    from ._6441 import SpiralBevelGearMeshCompoundDynamicAnalysis
    from ._6442 import SpiralBevelGearSetCompoundDynamicAnalysis
    from ._6443 import SpringDamperCompoundDynamicAnalysis
    from ._6444 import SpringDamperConnectionCompoundDynamicAnalysis
    from ._6445 import SpringDamperHalfCompoundDynamicAnalysis
    from ._6446 import StraightBevelDiffGearCompoundDynamicAnalysis
    from ._6447 import StraightBevelDiffGearMeshCompoundDynamicAnalysis
    from ._6448 import StraightBevelDiffGearSetCompoundDynamicAnalysis
    from ._6449 import StraightBevelGearCompoundDynamicAnalysis
    from ._6450 import StraightBevelGearMeshCompoundDynamicAnalysis
    from ._6451 import StraightBevelGearSetCompoundDynamicAnalysis
    from ._6452 import StraightBevelPlanetGearCompoundDynamicAnalysis
    from ._6453 import StraightBevelSunGearCompoundDynamicAnalysis
    from ._6454 import SynchroniserCompoundDynamicAnalysis
    from ._6455 import SynchroniserHalfCompoundDynamicAnalysis
    from ._6456 import SynchroniserPartCompoundDynamicAnalysis
    from ._6457 import SynchroniserSleeveCompoundDynamicAnalysis
    from ._6458 import TorqueConverterCompoundDynamicAnalysis
    from ._6459 import TorqueConverterConnectionCompoundDynamicAnalysis
    from ._6460 import TorqueConverterPumpCompoundDynamicAnalysis
    from ._6461 import TorqueConverterTurbineCompoundDynamicAnalysis
    from ._6462 import UnbalancedMassCompoundDynamicAnalysis
    from ._6463 import VirtualComponentCompoundDynamicAnalysis
    from ._6464 import WormGearCompoundDynamicAnalysis
    from ._6465 import WormGearMeshCompoundDynamicAnalysis
    from ._6466 import WormGearSetCompoundDynamicAnalysis
    from ._6467 import ZerolBevelGearCompoundDynamicAnalysis
    from ._6468 import ZerolBevelGearMeshCompoundDynamicAnalysis
    from ._6469 import ZerolBevelGearSetCompoundDynamicAnalysis



"""_6994.py

FaceGearAdvancedTimeSteppingAnalysisForModulation
"""


from mastapy.system_model.part_model.gears import _2484
from mastapy._internal import constructor
from mastapy.system_model.analyses_and_results.static_loads import _6816
from mastapy.system_model.analyses_and_results.system_deflections import _2707
from mastapy.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation import _6999
from mastapy._internal.python_net import python_net_import

_FACE_GEAR_ADVANCED_TIME_STEPPING_ANALYSIS_FOR_MODULATION = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.AdvancedTimeSteppingAnalysesForModulation', 'FaceGearAdvancedTimeSteppingAnalysisForModulation')


__docformat__ = 'restructuredtext en'
__all__ = ('FaceGearAdvancedTimeSteppingAnalysisForModulation',)


class FaceGearAdvancedTimeSteppingAnalysisForModulation(_6999.GearAdvancedTimeSteppingAnalysisForModulation):
    """FaceGearAdvancedTimeSteppingAnalysisForModulation

    This is a mastapy class.
    """

    TYPE = _FACE_GEAR_ADVANCED_TIME_STEPPING_ANALYSIS_FOR_MODULATION

    def __init__(self, instance_to_wrap: 'FaceGearAdvancedTimeSteppingAnalysisForModulation.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def component_design(self) -> '_2484.FaceGear':
        """FaceGear: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ComponentDesign

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def component_load_case(self) -> '_6816.FaceGearLoadCase':
        """FaceGearLoadCase: 'ComponentLoadCase' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ComponentLoadCase

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def system_deflection_results(self) -> '_2707.FaceGearSystemDeflection':
        """FaceGearSystemDeflection: 'SystemDeflectionResults' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.SystemDeflectionResults

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None



"""_2109.py

CageBridgeShape
"""


from enum import Enum

from mastapy._internal.python_net import python_net_import

_CAGE_BRIDGE_SHAPE = python_net_import('SMT.MastaAPI.Bearings.BearingDesigns.Rolling', 'CageBridgeShape')


__docformat__ = 'restructuredtext en'
__all__ = ('CageBridgeShape',)


class CageBridgeShape(Enum):
    """CageBridgeShape

    This is a mastapy class.

    Note:
        This class is an Enum.
    """

    @classmethod
    def type_(cls):
        return _CAGE_BRIDGE_SHAPE

    FLAT = 0
    CURVED = 1


def __enum_setattr(self, attr, value):
    raise AttributeError('Cannot set the attributes of an Enum.') from None


def __enum_delattr(self, attr):
    raise AttributeError('Cannot delete the attributes of an Enum.') from None


CageBridgeShape.__setattr__ = __enum_setattr
CageBridgeShape.__delattr__ = __enum_delattr



"""_1326.py

ElectricMachineLoadCase
"""


from mastapy._internal.implicit import enum_with_selected_value
from mastapy.nodal_analysis.elmer import _166
from mastapy._internal.overridable_constructor import _unpack_overridable
from mastapy._internal import enum_with_selected_value_runtime, conversion, constructor
from mastapy.electric_machines.load_cases_and_analyses import (
    _1329, _1333, _1325, _1327
)
from mastapy.electric_machines import _1252
from mastapy._internal.python_net import python_net_import

_ELECTRIC_MACHINE_LOAD_CASE = python_net_import('SMT.MastaAPI.ElectricMachines.LoadCasesAndAnalyses', 'ElectricMachineLoadCase')


__docformat__ = 'restructuredtext en'
__all__ = ('ElectricMachineLoadCase',)


class ElectricMachineLoadCase(_1327.ElectricMachineLoadCaseBase):
    """ElectricMachineLoadCase

    This is a mastapy class.
    """

    TYPE = _ELECTRIC_MACHINE_LOAD_CASE

    def __init__(self, instance_to_wrap: 'ElectricMachineLoadCase.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def analysis_period(self) -> 'enum_with_selected_value.EnumWithSelectedValue_ElectricMachineAnalysisPeriod':
        """enum_with_selected_value.EnumWithSelectedValue_ElectricMachineAnalysisPeriod: 'AnalysisPeriod' is the original name of this property."""

        temp = self.wrapped.AnalysisPeriod

        if temp is None:
            return None

        value = enum_with_selected_value.EnumWithSelectedValue_ElectricMachineAnalysisPeriod.wrapped_type()
        return enum_with_selected_value_runtime.create(temp, value) if temp is not None else None

    @analysis_period.setter
    def analysis_period(self, value: 'enum_with_selected_value.EnumWithSelectedValue_ElectricMachineAnalysisPeriod.implicit_type()'):
        wrapper_type = enum_with_selected_value_runtime.ENUM_WITH_SELECTED_VALUE
        enclosed_type = enum_with_selected_value.EnumWithSelectedValue_ElectricMachineAnalysisPeriod.implicit_type()
        value = conversion.mp_to_pn_enum(value)
        value = wrapper_type[enclosed_type](value)
        self.wrapped.AnalysisPeriod = value

    @property
    def core_loss_minor_loop_hysteresis_loss_factor(self) -> 'float':
        """float: 'CoreLossMinorLoopHysteresisLossFactor' is the original name of this property."""

        temp = self.wrapped.CoreLossMinorLoopHysteresisLossFactor

        if temp is None:
            return 0.0

        return temp

    @core_loss_minor_loop_hysteresis_loss_factor.setter
    def core_loss_minor_loop_hysteresis_loss_factor(self, value: 'float'):
        self.wrapped.CoreLossMinorLoopHysteresisLossFactor = float(value) if value is not None else 0.0

    @property
    def current_angle(self) -> 'float':
        """float: 'CurrentAngle' is the original name of this property."""

        temp = self.wrapped.CurrentAngle

        if temp is None:
            return 0.0

        return temp

    @current_angle.setter
    def current_angle(self, value: 'float'):
        self.wrapped.CurrentAngle = float(value) if value is not None else 0.0

    @property
    def end_winding_inductance_method(self) -> '_1329.EndWindingInductanceMethod':
        """EndWindingInductanceMethod: 'EndWindingInductanceMethod' is the original name of this property."""

        temp = self.wrapped.EndWindingInductanceMethod

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(temp)
        return constructor.new_from_mastapy_type(_1329.EndWindingInductanceMethod)(value) if value is not None else None

    @end_winding_inductance_method.setter
    def end_winding_inductance_method(self, value: '_1329.EndWindingInductanceMethod'):
        value = conversion.mp_to_pn_enum(value)
        self.wrapped.EndWindingInductanceMethod = value

    @property
    def include_iron_and_eddy_current_losses(self) -> 'bool':
        """bool: 'IncludeIronAndEddyCurrentLosses' is the original name of this property."""

        temp = self.wrapped.IncludeIronAndEddyCurrentLosses

        if temp is None:
            return False

        return temp

    @include_iron_and_eddy_current_losses.setter
    def include_iron_and_eddy_current_losses(self, value: 'bool'):
        self.wrapped.IncludeIronAndEddyCurrentLosses = bool(value) if value is not None else False

    @property
    def include_open_circuit_calculation(self) -> 'bool':
        """bool: 'IncludeOpenCircuitCalculation' is the original name of this property."""

        temp = self.wrapped.IncludeOpenCircuitCalculation

        if temp is None:
            return False

        return temp

    @include_open_circuit_calculation.setter
    def include_open_circuit_calculation(self, value: 'bool'):
        self.wrapped.IncludeOpenCircuitCalculation = bool(value) if value is not None else False

    @property
    def minimum_number_of_steps_for_voltages_and_losses_calculation(self) -> 'int':
        """int: 'MinimumNumberOfStepsForVoltagesAndLossesCalculation' is the original name of this property."""

        temp = self.wrapped.MinimumNumberOfStepsForVoltagesAndLossesCalculation

        if temp is None:
            return 0

        return temp

    @minimum_number_of_steps_for_voltages_and_losses_calculation.setter
    def minimum_number_of_steps_for_voltages_and_losses_calculation(self, value: 'int'):
        self.wrapped.MinimumNumberOfStepsForVoltagesAndLossesCalculation = int(value) if value is not None else 0

    @property
    def motoring_or_generating(self) -> '_1333.MotoringOrGenerating':
        """MotoringOrGenerating: 'MotoringOrGenerating' is the original name of this property."""

        temp = self.wrapped.MotoringOrGenerating

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(temp)
        return constructor.new_from_mastapy_type(_1333.MotoringOrGenerating)(value) if value is not None else None

    @motoring_or_generating.setter
    def motoring_or_generating(self, value: '_1333.MotoringOrGenerating'):
        value = conversion.mp_to_pn_enum(value)
        self.wrapped.MotoringOrGenerating = value

    @property
    def non_linear_system_convergence_tolerance(self) -> 'float':
        """float: 'NonLinearSystemConvergenceTolerance' is the original name of this property."""

        temp = self.wrapped.NonLinearSystemConvergenceTolerance

        if temp is None:
            return 0.0

        return temp

    @non_linear_system_convergence_tolerance.setter
    def non_linear_system_convergence_tolerance(self, value: 'float'):
        self.wrapped.NonLinearSystemConvergenceTolerance = float(value) if value is not None else 0.0

    @property
    def number_of_cycles(self) -> 'int':
        """int: 'NumberOfCycles' is the original name of this property."""

        temp = self.wrapped.NumberOfCycles

        if temp is None:
            return 0

        return temp

    @number_of_cycles.setter
    def number_of_cycles(self, value: 'int'):
        self.wrapped.NumberOfCycles = int(value) if value is not None else 0

    @property
    def number_of_steps_per_cycle(self) -> 'int':
        """int: 'NumberOfStepsPerCycle' is the original name of this property."""

        temp = self.wrapped.NumberOfStepsPerCycle

        if temp is None:
            return 0

        return temp

    @number_of_steps_per_cycle.setter
    def number_of_steps_per_cycle(self, value: 'int'):
        self.wrapped.NumberOfStepsPerCycle = int(value) if value is not None else 0

    @property
    def override_design_end_winding_inductance_method(self) -> 'bool':
        """bool: 'OverrideDesignEndWindingInductanceMethod' is the original name of this property."""

        temp = self.wrapped.OverrideDesignEndWindingInductanceMethod

        if temp is None:
            return False

        return temp

    @override_design_end_winding_inductance_method.setter
    def override_design_end_winding_inductance_method(self, value: 'bool'):
        self.wrapped.OverrideDesignEndWindingInductanceMethod = bool(value) if value is not None else False

    @property
    def peak_line_current(self) -> 'float':
        """float: 'PeakLineCurrent' is the original name of this property."""

        temp = self.wrapped.PeakLineCurrent

        if temp is None:
            return 0.0

        return temp

    @peak_line_current.setter
    def peak_line_current(self, value: 'float'):
        self.wrapped.PeakLineCurrent = float(value) if value is not None else 0.0

    @property
    def rms_line_current(self) -> 'float':
        """float: 'RMSLineCurrent' is the original name of this property."""

        temp = self.wrapped.RMSLineCurrent

        if temp is None:
            return 0.0

        return temp

    @rms_line_current.setter
    def rms_line_current(self, value: 'float'):
        self.wrapped.RMSLineCurrent = float(value) if value is not None else 0.0

    @property
    def speed(self) -> 'float':
        """float: 'Speed' is the original name of this property."""

        temp = self.wrapped.Speed

        if temp is None:
            return 0.0

        return temp

    @speed.setter
    def speed(self, value: 'float'):
        self.wrapped.Speed = float(value) if value is not None else 0.0

    @property
    def total_number_of_time_steps(self) -> 'int':
        """int: 'TotalNumberOfTimeSteps' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.TotalNumberOfTimeSteps

        if temp is None:
            return 0

        return temp

    @property
    def user_specified_end_winding_inductance(self) -> 'float':
        """float: 'UserSpecifiedEndWindingInductance' is the original name of this property."""

        temp = self.wrapped.UserSpecifiedEndWindingInductance

        if temp is None:
            return 0.0

        return temp

    @user_specified_end_winding_inductance.setter
    def user_specified_end_winding_inductance(self, value: 'float'):
        self.wrapped.UserSpecifiedEndWindingInductance = float(value) if value is not None else 0.0

    def analysis_for(self, setup: '_1252.ElectricMachineSetup') -> '_1325.ElectricMachineFEAnalysis':
        """ 'AnalysisFor' is the original name of this method.

        Args:
            setup (mastapy.electric_machines.ElectricMachineSetup)

        Returns:
            mastapy.electric_machines.load_cases_and_analyses.ElectricMachineFEAnalysis
        """

        method_result = self.wrapped.AnalysisFor(setup.wrapped if setup else None)
        type_ = method_result.GetType()
        return constructor.new(type_.Namespace, type_.Name)(method_result) if method_result is not None else None



"""_666.py

HobbingProcessSimulationNew
"""


from mastapy.gears.manufacturing.cylindrical.hobbing_process_simulation_new import (
    _660, _661, _662, _663,
    _664, _668, _679, _665
)
from mastapy._internal import constructor
from mastapy._internal.python_net import python_net_import

_HOBBING_PROCESS_SIMULATION_NEW = python_net_import('SMT.MastaAPI.Gears.Manufacturing.Cylindrical.HobbingProcessSimulationNew', 'HobbingProcessSimulationNew')


__docformat__ = 'restructuredtext en'
__all__ = ('HobbingProcessSimulationNew',)


class HobbingProcessSimulationNew(_679.ProcessSimulationNew['_665.HobbingProcessSimulationInput']):
    """HobbingProcessSimulationNew

    This is a mastapy class.
    """

    TYPE = _HOBBING_PROCESS_SIMULATION_NEW

    def __init__(self, instance_to_wrap: 'HobbingProcessSimulationNew.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def hobbing_process_gear_shape_calculation(self) -> '_660.HobbingProcessGearShape':
        """HobbingProcessGearShape: 'HobbingProcessGearShapeCalculation' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.HobbingProcessGearShapeCalculation

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def hobbing_process_lead_calculation(self) -> '_661.HobbingProcessLeadCalculation':
        """HobbingProcessLeadCalculation: 'HobbingProcessLeadCalculation' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.HobbingProcessLeadCalculation

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def hobbing_process_mark_on_shaft_calculation(self) -> '_662.HobbingProcessMarkOnShaft':
        """HobbingProcessMarkOnShaft: 'HobbingProcessMarkOnShaftCalculation' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.HobbingProcessMarkOnShaftCalculation

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def hobbing_process_pitch_calculation(self) -> '_663.HobbingProcessPitchCalculation':
        """HobbingProcessPitchCalculation: 'HobbingProcessPitchCalculation' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.HobbingProcessPitchCalculation

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def hobbing_process_profile_calculation(self) -> '_664.HobbingProcessProfileCalculation':
        """HobbingProcessProfileCalculation: 'HobbingProcessProfileCalculation' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.HobbingProcessProfileCalculation

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def hobbing_process_total_modification(self) -> '_668.HobbingProcessTotalModificationCalculation':
        """HobbingProcessTotalModificationCalculation: 'HobbingProcessTotalModification' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.HobbingProcessTotalModification

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None



"""__init__.py"""


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._1124 import AGMA2000AccuracyGrader
    from ._1125 import AGMA20151AccuracyGrader
    from ._1126 import AGMA20151AccuracyGrades
    from ._1127 import AGMAISO13282013AccuracyGrader
    from ._1128 import CylindricalAccuracyGrader
    from ._1129 import CylindricalAccuracyGraderWithProfileFormAndSlope
    from ._1130 import CylindricalAccuracyGrades
    from ._1131 import DIN3967SystemOfGearFits
    from ._1132 import ISO13282013AccuracyGrader
    from ._1133 import ISO1328AccuracyGrader
    from ._1134 import ISO1328AccuracyGraderCommon
    from ._1135 import ISO1328AccuracyGrades



"""_366.py

WormGearDutyCycleRating
"""


from typing import List

from mastapy.gears.rating import _353, _352
from mastapy._internal import constructor, conversion
from mastapy.gears.rating.cylindrical import _450, _451
from mastapy._internal.cast_exception import CastException
from mastapy.gears.rating.worm import _369, _368
from mastapy._internal.python_net import python_net_import

_WORM_GEAR_DUTY_CYCLE_RATING = python_net_import('SMT.MastaAPI.Gears.Rating.Worm', 'WormGearDutyCycleRating')


__docformat__ = 'restructuredtext en'
__all__ = ('WormGearDutyCycleRating',)


class WormGearDutyCycleRating(_352.GearDutyCycleRating):
    """WormGearDutyCycleRating

    This is a mastapy class.
    """

    TYPE = _WORM_GEAR_DUTY_CYCLE_RATING

    def __init__(self, instance_to_wrap: 'WormGearDutyCycleRating.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def left_flank_rating(self) -> '_353.GearFlankRating':
        """GearFlankRating: 'LeftFlankRating' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.LeftFlankRating

        if temp is None:
            return None

        if _353.GearFlankRating.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast left_flank_rating to GearFlankRating. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def right_flank_rating(self) -> '_353.GearFlankRating':
        """GearFlankRating: 'RightFlankRating' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.RightFlankRating

        if temp is None:
            return None

        if _353.GearFlankRating.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast right_flank_rating to GearFlankRating. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def gear_set_design_duty_cycle(self) -> '_369.WormGearSetDutyCycleRating':
        """WormGearSetDutyCycleRating: 'GearSetDesignDutyCycle' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.GearSetDesignDutyCycle

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def worm_gear_set_design_duty_cycle(self) -> '_369.WormGearSetDutyCycleRating':
        """WormGearSetDutyCycleRating: 'WormGearSetDesignDutyCycle' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.WormGearSetDesignDutyCycle

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def gear_ratings(self) -> 'List[_368.WormGearRating]':
        """List[WormGearRating]: 'GearRatings' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.GearRatings

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)
        return value

    @property
    def worm_gear_ratings(self) -> 'List[_368.WormGearRating]':
        """List[WormGearRating]: 'WormGearRatings' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.WormGearRatings

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)
        return value



"""__init__.py"""


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._6211 import AbstractAssemblyDynamicAnalysis
    from ._6212 import AbstractShaftDynamicAnalysis
    from ._6213 import AbstractShaftOrHousingDynamicAnalysis
    from ._6214 import AbstractShaftToMountableComponentConnectionDynamicAnalysis
    from ._6215 import AGMAGleasonConicalGearDynamicAnalysis
    from ._6216 import AGMAGleasonConicalGearMeshDynamicAnalysis
    from ._6217 import AGMAGleasonConicalGearSetDynamicAnalysis
    from ._6218 import AssemblyDynamicAnalysis
    from ._6219 import BearingDynamicAnalysis
    from ._6220 import BeltConnectionDynamicAnalysis
    from ._6221 import BeltDriveDynamicAnalysis
    from ._6222 import BevelDifferentialGearDynamicAnalysis
    from ._6223 import BevelDifferentialGearMeshDynamicAnalysis
    from ._6224 import BevelDifferentialGearSetDynamicAnalysis
    from ._6225 import BevelDifferentialPlanetGearDynamicAnalysis
    from ._6226 import BevelDifferentialSunGearDynamicAnalysis
    from ._6227 import BevelGearDynamicAnalysis
    from ._6228 import BevelGearMeshDynamicAnalysis
    from ._6229 import BevelGearSetDynamicAnalysis
    from ._6230 import BoltDynamicAnalysis
    from ._6231 import BoltedJointDynamicAnalysis
    from ._6232 import ClutchConnectionDynamicAnalysis
    from ._6233 import ClutchDynamicAnalysis
    from ._6234 import ClutchHalfDynamicAnalysis
    from ._6235 import CoaxialConnectionDynamicAnalysis
    from ._6236 import ComponentDynamicAnalysis
    from ._6237 import ConceptCouplingConnectionDynamicAnalysis
    from ._6238 import ConceptCouplingDynamicAnalysis
    from ._6239 import ConceptCouplingHalfDynamicAnalysis
    from ._6240 import ConceptGearDynamicAnalysis
    from ._6241 import ConceptGearMeshDynamicAnalysis
    from ._6242 import ConceptGearSetDynamicAnalysis
    from ._6243 import ConicalGearDynamicAnalysis
    from ._6244 import ConicalGearMeshDynamicAnalysis
    from ._6245 import ConicalGearSetDynamicAnalysis
    from ._6246 import ConnectionDynamicAnalysis
    from ._6247 import ConnectorDynamicAnalysis
    from ._6248 import CouplingConnectionDynamicAnalysis
    from ._6249 import CouplingDynamicAnalysis
    from ._6250 import CouplingHalfDynamicAnalysis
    from ._6251 import CVTBeltConnectionDynamicAnalysis
    from ._6252 import CVTDynamicAnalysis
    from ._6253 import CVTPulleyDynamicAnalysis
    from ._6254 import CycloidalAssemblyDynamicAnalysis
    from ._6255 import CycloidalDiscCentralBearingConnectionDynamicAnalysis
    from ._6256 import CycloidalDiscDynamicAnalysis
    from ._6257 import CycloidalDiscPlanetaryBearingConnectionDynamicAnalysis
    from ._6258 import CylindricalGearDynamicAnalysis
    from ._6259 import CylindricalGearMeshDynamicAnalysis
    from ._6260 import CylindricalGearSetDynamicAnalysis
    from ._6261 import CylindricalPlanetGearDynamicAnalysis
    from ._6262 import DatumDynamicAnalysis
    from ._2582 import DynamicAnalysis
    from ._6263 import DynamicAnalysisDrawStyle
    from ._6264 import ExternalCADModelDynamicAnalysis
    from ._6265 import FaceGearDynamicAnalysis
    from ._6266 import FaceGearMeshDynamicAnalysis
    from ._6267 import FaceGearSetDynamicAnalysis
    from ._6268 import FEPartDynamicAnalysis
    from ._6269 import FlexiblePinAssemblyDynamicAnalysis
    from ._6270 import GearDynamicAnalysis
    from ._6271 import GearMeshDynamicAnalysis
    from ._6272 import GearSetDynamicAnalysis
    from ._6273 import GuideDxfModelDynamicAnalysis
    from ._6274 import HypoidGearDynamicAnalysis
    from ._6275 import HypoidGearMeshDynamicAnalysis
    from ._6276 import HypoidGearSetDynamicAnalysis
    from ._6277 import InterMountableComponentConnectionDynamicAnalysis
    from ._6278 import KlingelnbergCycloPalloidConicalGearDynamicAnalysis
    from ._6279 import KlingelnbergCycloPalloidConicalGearMeshDynamicAnalysis
    from ._6280 import KlingelnbergCycloPalloidConicalGearSetDynamicAnalysis
    from ._6281 import KlingelnbergCycloPalloidHypoidGearDynamicAnalysis
    from ._6282 import KlingelnbergCycloPalloidHypoidGearMeshDynamicAnalysis
    from ._6283 import KlingelnbergCycloPalloidHypoidGearSetDynamicAnalysis
    from ._6284 import KlingelnbergCycloPalloidSpiralBevelGearDynamicAnalysis
    from ._6285 import KlingelnbergCycloPalloidSpiralBevelGearMeshDynamicAnalysis
    from ._6286 import KlingelnbergCycloPalloidSpiralBevelGearSetDynamicAnalysis
    from ._6287 import MassDiscDynamicAnalysis
    from ._6288 import MeasurementComponentDynamicAnalysis
    from ._6289 import MountableComponentDynamicAnalysis
    from ._6290 import OilSealDynamicAnalysis
    from ._6291 import PartDynamicAnalysis
    from ._6292 import PartToPartShearCouplingConnectionDynamicAnalysis
    from ._6293 import PartToPartShearCouplingDynamicAnalysis
    from ._6294 import PartToPartShearCouplingHalfDynamicAnalysis
    from ._6295 import PlanetaryConnectionDynamicAnalysis
    from ._6296 import PlanetaryGearSetDynamicAnalysis
    from ._6297 import PlanetCarrierDynamicAnalysis
    from ._6298 import PointLoadDynamicAnalysis
    from ._6299 import PowerLoadDynamicAnalysis
    from ._6300 import PulleyDynamicAnalysis
    from ._6301 import RingPinsDynamicAnalysis
    from ._6302 import RingPinsToDiscConnectionDynamicAnalysis
    from ._6303 import RollingRingAssemblyDynamicAnalysis
    from ._6304 import RollingRingConnectionDynamicAnalysis
    from ._6305 import RollingRingDynamicAnalysis
    from ._6306 import RootAssemblyDynamicAnalysis
    from ._6307 import ShaftDynamicAnalysis
    from ._6308 import ShaftHubConnectionDynamicAnalysis
    from ._6309 import ShaftToMountableComponentConnectionDynamicAnalysis
    from ._6310 import SpecialisedAssemblyDynamicAnalysis
    from ._6311 import SpiralBevelGearDynamicAnalysis
    from ._6312 import SpiralBevelGearMeshDynamicAnalysis
    from ._6313 import SpiralBevelGearSetDynamicAnalysis
    from ._6314 import SpringDamperConnectionDynamicAnalysis
    from ._6315 import SpringDamperDynamicAnalysis
    from ._6316 import SpringDamperHalfDynamicAnalysis
    from ._6317 import StraightBevelDiffGearDynamicAnalysis
    from ._6318 import StraightBevelDiffGearMeshDynamicAnalysis
    from ._6319 import StraightBevelDiffGearSetDynamicAnalysis
    from ._6320 import StraightBevelGearDynamicAnalysis
    from ._6321 import StraightBevelGearMeshDynamicAnalysis
    from ._6322 import StraightBevelGearSetDynamicAnalysis
    from ._6323 import StraightBevelPlanetGearDynamicAnalysis
    from ._6324 import StraightBevelSunGearDynamicAnalysis
    from ._6325 import SynchroniserDynamicAnalysis
    from ._6326 import SynchroniserHalfDynamicAnalysis
    from ._6327 import SynchroniserPartDynamicAnalysis
    from ._6328 import SynchroniserSleeveDynamicAnalysis
    from ._6329 import TorqueConverterConnectionDynamicAnalysis
    from ._6330 import TorqueConverterDynamicAnalysis
    from ._6331 import TorqueConverterPumpDynamicAnalysis
    from ._6332 import TorqueConverterTurbineDynamicAnalysis
    from ._6333 import UnbalancedMassDynamicAnalysis
    from ._6334 import VirtualComponentDynamicAnalysis
    from ._6335 import WormGearDynamicAnalysis
    from ._6336 import WormGearMeshDynamicAnalysis
    from ._6337 import WormGearSetDynamicAnalysis
    from ._6338 import ZerolBevelGearDynamicAnalysis
    from ._6339 import ZerolBevelGearMeshDynamicAnalysis
    from ._6340 import ZerolBevelGearSetDynamicAnalysis



"""__init__.py"""


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._5943 import AbstractAssemblyHarmonicAnalysisOfSingleExcitation
    from ._5944 import AbstractShaftHarmonicAnalysisOfSingleExcitation
    from ._5945 import AbstractShaftOrHousingHarmonicAnalysisOfSingleExcitation
    from ._5946 import AbstractShaftToMountableComponentConnectionHarmonicAnalysisOfSingleExcitation
    from ._5947 import AGMAGleasonConicalGearHarmonicAnalysisOfSingleExcitation
    from ._5948 import AGMAGleasonConicalGearMeshHarmonicAnalysisOfSingleExcitation
    from ._5949 import AGMAGleasonConicalGearSetHarmonicAnalysisOfSingleExcitation
    from ._5950 import AssemblyHarmonicAnalysisOfSingleExcitation
    from ._5951 import BearingHarmonicAnalysisOfSingleExcitation
    from ._5952 import BeltConnectionHarmonicAnalysisOfSingleExcitation
    from ._5953 import BeltDriveHarmonicAnalysisOfSingleExcitation
    from ._5954 import BevelDifferentialGearHarmonicAnalysisOfSingleExcitation
    from ._5955 import BevelDifferentialGearMeshHarmonicAnalysisOfSingleExcitation
    from ._5956 import BevelDifferentialGearSetHarmonicAnalysisOfSingleExcitation
    from ._5957 import BevelDifferentialPlanetGearHarmonicAnalysisOfSingleExcitation
    from ._5958 import BevelDifferentialSunGearHarmonicAnalysisOfSingleExcitation
    from ._5959 import BevelGearHarmonicAnalysisOfSingleExcitation
    from ._5960 import BevelGearMeshHarmonicAnalysisOfSingleExcitation
    from ._5961 import BevelGearSetHarmonicAnalysisOfSingleExcitation
    from ._5962 import BoltedJointHarmonicAnalysisOfSingleExcitation
    from ._5963 import BoltHarmonicAnalysisOfSingleExcitation
    from ._5964 import ClutchConnectionHarmonicAnalysisOfSingleExcitation
    from ._5965 import ClutchHalfHarmonicAnalysisOfSingleExcitation
    from ._5966 import ClutchHarmonicAnalysisOfSingleExcitation
    from ._5967 import CoaxialConnectionHarmonicAnalysisOfSingleExcitation
    from ._5968 import ComponentHarmonicAnalysisOfSingleExcitation
    from ._5969 import ConceptCouplingConnectionHarmonicAnalysisOfSingleExcitation
    from ._5970 import ConceptCouplingHalfHarmonicAnalysisOfSingleExcitation
    from ._5971 import ConceptCouplingHarmonicAnalysisOfSingleExcitation
    from ._5972 import ConceptGearHarmonicAnalysisOfSingleExcitation
    from ._5973 import ConceptGearMeshHarmonicAnalysisOfSingleExcitation
    from ._5974 import ConceptGearSetHarmonicAnalysisOfSingleExcitation
    from ._5975 import ConicalGearHarmonicAnalysisOfSingleExcitation
    from ._5976 import ConicalGearMeshHarmonicAnalysisOfSingleExcitation
    from ._5977 import ConicalGearSetHarmonicAnalysisOfSingleExcitation
    from ._5978 import ConnectionHarmonicAnalysisOfSingleExcitation
    from ._5979 import ConnectorHarmonicAnalysisOfSingleExcitation
    from ._5980 import CouplingConnectionHarmonicAnalysisOfSingleExcitation
    from ._5981 import CouplingHalfHarmonicAnalysisOfSingleExcitation
    from ._5982 import CouplingHarmonicAnalysisOfSingleExcitation
    from ._5983 import CVTBeltConnectionHarmonicAnalysisOfSingleExcitation
    from ._5984 import CVTHarmonicAnalysisOfSingleExcitation
    from ._5985 import CVTPulleyHarmonicAnalysisOfSingleExcitation
    from ._5986 import CycloidalAssemblyHarmonicAnalysisOfSingleExcitation
    from ._5987 import CycloidalDiscCentralBearingConnectionHarmonicAnalysisOfSingleExcitation
    from ._5988 import CycloidalDiscHarmonicAnalysisOfSingleExcitation
    from ._5989 import CycloidalDiscPlanetaryBearingConnectionHarmonicAnalysisOfSingleExcitation
    from ._5990 import CylindricalGearHarmonicAnalysisOfSingleExcitation
    from ._5991 import CylindricalGearMeshHarmonicAnalysisOfSingleExcitation
    from ._5992 import CylindricalGearSetHarmonicAnalysisOfSingleExcitation
    from ._5993 import CylindricalPlanetGearHarmonicAnalysisOfSingleExcitation
    from ._5994 import DatumHarmonicAnalysisOfSingleExcitation
    from ._5995 import ExternalCADModelHarmonicAnalysisOfSingleExcitation
    from ._5996 import FaceGearHarmonicAnalysisOfSingleExcitation
    from ._5997 import FaceGearMeshHarmonicAnalysisOfSingleExcitation
    from ._5998 import FaceGearSetHarmonicAnalysisOfSingleExcitation
    from ._5999 import FEPartHarmonicAnalysisOfSingleExcitation
    from ._6000 import FlexiblePinAssemblyHarmonicAnalysisOfSingleExcitation
    from ._6001 import GearHarmonicAnalysisOfSingleExcitation
    from ._6002 import GearMeshHarmonicAnalysisOfSingleExcitation
    from ._6003 import GearSetHarmonicAnalysisOfSingleExcitation
    from ._6004 import GuideDxfModelHarmonicAnalysisOfSingleExcitation
    from ._6005 import HarmonicAnalysisOfSingleExcitation
    from ._6006 import HypoidGearHarmonicAnalysisOfSingleExcitation
    from ._6007 import HypoidGearMeshHarmonicAnalysisOfSingleExcitation
    from ._6008 import HypoidGearSetHarmonicAnalysisOfSingleExcitation
    from ._6009 import InterMountableComponentConnectionHarmonicAnalysisOfSingleExcitation
    from ._6010 import KlingelnbergCycloPalloidConicalGearHarmonicAnalysisOfSingleExcitation
    from ._6011 import KlingelnbergCycloPalloidConicalGearMeshHarmonicAnalysisOfSingleExcitation
    from ._6012 import KlingelnbergCycloPalloidConicalGearSetHarmonicAnalysisOfSingleExcitation
    from ._6013 import KlingelnbergCycloPalloidHypoidGearHarmonicAnalysisOfSingleExcitation
    from ._6014 import KlingelnbergCycloPalloidHypoidGearMeshHarmonicAnalysisOfSingleExcitation
    from ._6015 import KlingelnbergCycloPalloidHypoidGearSetHarmonicAnalysisOfSingleExcitation
    from ._6016 import KlingelnbergCycloPalloidSpiralBevelGearHarmonicAnalysisOfSingleExcitation
    from ._6017 import KlingelnbergCycloPalloidSpiralBevelGearMeshHarmonicAnalysisOfSingleExcitation
    from ._6018 import KlingelnbergCycloPalloidSpiralBevelGearSetHarmonicAnalysisOfSingleExcitation
    from ._6019 import MassDiscHarmonicAnalysisOfSingleExcitation
    from ._6020 import MeasurementComponentHarmonicAnalysisOfSingleExcitation
    from ._2594 import ModalAnalysisForHarmonicAnalysis
    from ._6021 import MountableComponentHarmonicAnalysisOfSingleExcitation
    from ._6022 import OilSealHarmonicAnalysisOfSingleExcitation
    from ._6023 import PartHarmonicAnalysisOfSingleExcitation
    from ._6024 import PartToPartShearCouplingConnectionHarmonicAnalysisOfSingleExcitation
    from ._6025 import PartToPartShearCouplingHalfHarmonicAnalysisOfSingleExcitation
    from ._6026 import PartToPartShearCouplingHarmonicAnalysisOfSingleExcitation
    from ._6027 import PlanetaryConnectionHarmonicAnalysisOfSingleExcitation
    from ._6028 import PlanetaryGearSetHarmonicAnalysisOfSingleExcitation
    from ._6029 import PlanetCarrierHarmonicAnalysisOfSingleExcitation
    from ._6030 import PointLoadHarmonicAnalysisOfSingleExcitation
    from ._6031 import PowerLoadHarmonicAnalysisOfSingleExcitation
    from ._6032 import PulleyHarmonicAnalysisOfSingleExcitation
    from ._6033 import RingPinsHarmonicAnalysisOfSingleExcitation
    from ._6034 import RingPinsToDiscConnectionHarmonicAnalysisOfSingleExcitation
    from ._6035 import RollingRingAssemblyHarmonicAnalysisOfSingleExcitation
    from ._6036 import RollingRingConnectionHarmonicAnalysisOfSingleExcitation
    from ._6037 import RollingRingHarmonicAnalysisOfSingleExcitation
    from ._6038 import RootAssemblyHarmonicAnalysisOfSingleExcitation
    from ._6039 import ShaftHarmonicAnalysisOfSingleExcitation
    from ._6040 import ShaftHubConnectionHarmonicAnalysisOfSingleExcitation
    from ._6041 import ShaftToMountableComponentConnectionHarmonicAnalysisOfSingleExcitation
    from ._6042 import SpecialisedAssemblyHarmonicAnalysisOfSingleExcitation
    from ._6043 import SpiralBevelGearHarmonicAnalysisOfSingleExcitation
    from ._6044 import SpiralBevelGearMeshHarmonicAnalysisOfSingleExcitation
    from ._6045 import SpiralBevelGearSetHarmonicAnalysisOfSingleExcitation
    from ._6046 import SpringDamperConnectionHarmonicAnalysisOfSingleExcitation
    from ._6047 import SpringDamperHalfHarmonicAnalysisOfSingleExcitation
    from ._6048 import SpringDamperHarmonicAnalysisOfSingleExcitation
    from ._6049 import StraightBevelDiffGearHarmonicAnalysisOfSingleExcitation
    from ._6050 import StraightBevelDiffGearMeshHarmonicAnalysisOfSingleExcitation
    from ._6051 import StraightBevelDiffGearSetHarmonicAnalysisOfSingleExcitation
    from ._6052 import StraightBevelGearHarmonicAnalysisOfSingleExcitation
    from ._6053 import StraightBevelGearMeshHarmonicAnalysisOfSingleExcitation
    from ._6054 import StraightBevelGearSetHarmonicAnalysisOfSingleExcitation
    from ._6055 import StraightBevelPlanetGearHarmonicAnalysisOfSingleExcitation
    from ._6056 import StraightBevelSunGearHarmonicAnalysisOfSingleExcitation
    from ._6057 import SynchroniserHalfHarmonicAnalysisOfSingleExcitation
    from ._6058 import SynchroniserHarmonicAnalysisOfSingleExcitation
    from ._6059 import SynchroniserPartHarmonicAnalysisOfSingleExcitation
    from ._6060 import SynchroniserSleeveHarmonicAnalysisOfSingleExcitation
    from ._6061 import TorqueConverterConnectionHarmonicAnalysisOfSingleExcitation
    from ._6062 import TorqueConverterHarmonicAnalysisOfSingleExcitation
    from ._6063 import TorqueConverterPumpHarmonicAnalysisOfSingleExcitation
    from ._6064 import TorqueConverterTurbineHarmonicAnalysisOfSingleExcitation
    from ._6065 import UnbalancedMassHarmonicAnalysisOfSingleExcitation
    from ._6066 import VirtualComponentHarmonicAnalysisOfSingleExcitation
    from ._6067 import WormGearHarmonicAnalysisOfSingleExcitation
    from ._6068 import WormGearMeshHarmonicAnalysisOfSingleExcitation
    from ._6069 import WormGearSetHarmonicAnalysisOfSingleExcitation
    from ._6070 import ZerolBevelGearHarmonicAnalysisOfSingleExcitation
    from ._6071 import ZerolBevelGearMeshHarmonicAnalysisOfSingleExcitation
    from ._6072 import ZerolBevelGearSetHarmonicAnalysisOfSingleExcitation



"""__init__.py"""


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._2077 import ANSIABMA112014Results
    from ._2078 import ANSIABMA92015Results
    from ._2079 import ANSIABMAResults



"""__init__.py"""


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._2532 import BeltDrive
    from ._2533 import BeltDriveType
    from ._2534 import Clutch
    from ._2535 import ClutchHalf
    from ._2536 import ClutchType
    from ._2537 import ConceptCoupling
    from ._2538 import ConceptCouplingHalf
    from ._2539 import Coupling
    from ._2540 import CouplingHalf
    from ._2541 import CrowningSpecification
    from ._2542 import CVT
    from ._2543 import CVTPulley
    from ._2544 import PartToPartShearCoupling
    from ._2545 import PartToPartShearCouplingHalf
    from ._2546 import Pulley
    from ._2547 import RigidConnectorStiffnessType
    from ._2548 import RigidConnectorTiltStiffnessTypes
    from ._2549 import RigidConnectorToothLocation
    from ._2550 import RigidConnectorToothSpacingType
    from ._2551 import RigidConnectorTypes
    from ._2552 import RollingRing
    from ._2553 import RollingRingAssembly
    from ._2554 import ShaftHubConnection
    from ._2555 import SplineLeadRelief
    from ._2556 import SpringDamper
    from ._2557 import SpringDamperHalf
    from ._2558 import Synchroniser
    from ._2559 import SynchroniserCone
    from ._2560 import SynchroniserHalf
    from ._2561 import SynchroniserPart
    from ._2562 import SynchroniserSleeve
    from ._2563 import TorqueConverter
    from ._2564 import TorqueConverterPump
    from ._2565 import TorqueConverterSpeedRatio
    from ._2566 import TorqueConverterTurbine



"""__init__.py"""


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._1526 import AbstractForceAndDisplacementResults
    from ._1527 import ForceAndDisplacementResults
    from ._1528 import ForceResults
    from ._1529 import NodeResults
    from ._1530 import OverridableDisplacementBoundaryCondition
    from ._1531 import VectorWithLinearAndAngularComponents



"""_5952.py

BeltConnectionHarmonicAnalysisOfSingleExcitation
"""


from mastapy.system_model.connections_and_sockets import _2227, _2232
from mastapy._internal import constructor
from mastapy._internal.cast_exception import CastException
from mastapy.system_model.analyses_and_results.static_loads import _6753, _6786
from mastapy.system_model.analyses_and_results.harmonic_analyses_single_excitation import _6009
from mastapy._internal.python_net import python_net_import

_BELT_CONNECTION_HARMONIC_ANALYSIS_OF_SINGLE_EXCITATION = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.HarmonicAnalysesSingleExcitation', 'BeltConnectionHarmonicAnalysisOfSingleExcitation')


__docformat__ = 'restructuredtext en'
__all__ = ('BeltConnectionHarmonicAnalysisOfSingleExcitation',)


class BeltConnectionHarmonicAnalysisOfSingleExcitation(_6009.InterMountableComponentConnectionHarmonicAnalysisOfSingleExcitation):
    """BeltConnectionHarmonicAnalysisOfSingleExcitation

    This is a mastapy class.
    """

    TYPE = _BELT_CONNECTION_HARMONIC_ANALYSIS_OF_SINGLE_EXCITATION

    def __init__(self, instance_to_wrap: 'BeltConnectionHarmonicAnalysisOfSingleExcitation.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def connection_design(self) -> '_2227.BeltConnection':
        """BeltConnection: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ConnectionDesign

        if temp is None:
            return None

        if _2227.BeltConnection.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast connection_design to BeltConnection. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def connection_load_case(self) -> '_6753.BeltConnectionLoadCase':
        """BeltConnectionLoadCase: 'ConnectionLoadCase' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ConnectionLoadCase

        if temp is None:
            return None

        if _6753.BeltConnectionLoadCase.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast connection_load_case to BeltConnectionLoadCase. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None
